==> rearm-2.4.9%2B1.21.1-fabric-sources.jar: me/pajic/rearm/ability/BashAbility.java <==
package me.pajic.rearm.ability;

import me.pajic.rearm.ReArm;
import me.pajic.rearm.enchantment.ReArmEnchantments;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1890;
import net.minecraft.class_2398;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_7924;
import net.minecraft.class_8710;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import org.jetbrains.annotations.NotNull;

import java.util.List;

public class BashAbility {

    public static final class_2960 BASH_SIGNAL = ReArm.id("bash_signal");

    public record C2SBashSignal() implements class_8710 {
        public static final class_9154<C2SBashSignal> TYPE = new class_9154<>(BASH_SIGNAL);
        public static final class_9139<class_9129, C2SBashSignal> CODEC = class_9139.method_56431(new C2SBashSignal());

        @Override
        public @NotNull class_9154<? extends class_8710> method_56479() {
            return TYPE;
        }
    }

	@SuppressWarnings({"deprecation", "resource"})
	public static void handleBash(C2SBashSignal signal, class_3222 player) {
		class_3218 level = player./*? if 1.21.1 {*/method_51469/*?} else {*//*level*//*?}*/();
		int bashLevel = class_1890.method_8225(
				//? if 1.21.1
				level.method_30349().method_30530(class_7924.field_41265).method_40290(ReArmEnchantments.BASH),
				//? if > 1.21.1
				/*level.registryAccess().lookupOrThrow(Registries.ENCHANTMENT).getOrThrow(ReArmEnchantments.BASH),*/
				player.method_6030()
		);
		if (bashLevel > 0 && player.method_6039()) {
			double bashRange = ReArm.CONFIG.shield.bashBaseRange.get() + bashLevel * ReArm.CONFIG.shield.bashRangePerLevel.get();
			List<class_1309> targets = level.method_18467(class_1309.class, player.method_5829().method_1009(bashRange, 1, bashRange))
					.stream().filter(livingEntity -> livingEntity != player).toList();
			if (!targets.isEmpty()) {
				targets.forEach(entity -> {
					entity.method_6005(
							ReArm.CONFIG.shield.bashBaseKnockback.get() + bashLevel * ReArm.CONFIG.shield.bashKnockbackPerLevel.get(),
							class_3532.method_15374(player.method_36454() * (float) (Math.PI / 180.0)), -class_3532.method_15362(player.method_36454() * (float) (Math.PI / 180.0))
					);
					entity.method_5643(
							level.method_48963().method_48802(player),
							ReArm.CONFIG.shield.bashBaseDamage.get() + 2 * ReArm.CONFIG.shield.bashDamagePerLevel.get()
					);
					level.method_14199(
							class_2398.field_11205, entity.method_23317(), entity.method_23318() + 0.5, entity.method_23321(),
							8, 0.3, 0.3, 0.3, 0.2
					);
				});
				level.method_8396(
						null, player.method_23312(), class_3417.field_15150/*? if >= 1.21.7 {*//*.value()*//*?}*/,
						class_3419.field_15248, 1.0F, 0.2F + level.field_9229.method_43057() * 0.3F
				);
				//? if 1.21.1 {
                            level.method_30349().method_30530(class_7924.field_41197).method_40266(ReArm.SHIELDS).ifPresent(tag ->
                                    tag.forEach(item -> player.method_7357().method_7906(item.comp_349(), ReArm.CONFIG.shield.bashShieldCooldown.get() * 20))
                            );
                            //?} else {
				/*level.registryAccess().lookupOrThrow(Registries.ITEM).getTagOrEmpty(ReArm.SHIELDS).forEach(item ->
						player.getCooldowns().addCooldown(level.registryAccess().lookupOrThrow(Registries.ITEM).getKey(item.value()), ReArm.CONFIG.shield.bashShieldCooldown.get() * 20)
				);
				*///?}
				player.method_6030().method_7970(
						targets.size(), player,
						player.method_6047().method_31574(player.method_6030().method_7909()) ? class_1304.field_6173 : class_1304.field_6171
				);
				player.method_6021();
			}
		}
	}
}

==> rearm-2.4.10%2B1.21.10-fabric-sources.jar: me/pajic/rearm/ability/BashAbility.java <==
package me.pajic.rearm.ability;

import me.pajic.rearm.ReArm;
import me.pajic.rearm.enchantment.ReArmEnchantments;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1890;
import net.minecraft.class_2398;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_7924;
import net.minecraft.class_8710;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import org.jetbrains.annotations.NotNull;

import java.util.List;

public class BashAbility {

    public static final class_2960 BASH_SIGNAL = ReArm.id("bash_signal");

    public record C2SBashSignal() implements class_8710 {
        public static final class_9154<C2SBashSignal> TYPE = new class_9154<>(BASH_SIGNAL);
        public static final class_9139<class_9129, C2SBashSignal> CODEC = class_9139.method_56431(new C2SBashSignal());

        @Override
        public @NotNull class_9154<? extends class_8710> method_56479() {
            return TYPE;
        }
    }

	@SuppressWarnings({"deprecation", "resource"})
	public static void handleBash(C2SBashSignal signal, class_3222 player) {
		class_3218 level = player./*? if 1.21.1 {*//*serverLevel*//*?} else {*/method_51469/*?}*/();
		int bashLevel = class_1890.method_8225(
				//? if 1.21.1
				/*level.registryAccess().registryOrThrow(Registries.ENCHANTMENT).getHolderOrThrow(ReArmEnchantments.BASH),*/
				//? if > 1.21.1
				level.method_30349().method_30530(class_7924.field_41265).method_46747(ReArmEnchantments.BASH),
				player.method_6030()
		);
		if (bashLevel > 0 && player.method_6039()) {
			double bashRange = ReArm.CONFIG.shield.bashBaseRange.get() + bashLevel * ReArm.CONFIG.shield.bashRangePerLevel.get();
			List<class_1309> targets = level.method_18467(class_1309.class, player.method_5829().method_1009(bashRange, 1, bashRange))
					.stream().filter(livingEntity -> livingEntity != player).toList();
			if (!targets.isEmpty()) {
				targets.forEach(entity -> {
					entity.method_6005(
							ReArm.CONFIG.shield.bashBaseKnockback.get() + bashLevel * ReArm.CONFIG.shield.bashKnockbackPerLevel.get(),
							class_3532.method_15374(player.method_36454() * (float) (Math.PI / 180.0)), -class_3532.method_15362(player.method_36454() * (float) (Math.PI / 180.0))
					);
					entity.method_64419(
							level.method_48963().method_48802(player),
							ReArm.CONFIG.shield.bashBaseDamage.get() + 2 * ReArm.CONFIG.shield.bashDamagePerLevel.get()
					);
					level.method_65096(
							class_2398.field_11205, entity.method_23317(), entity.method_23318() + 0.5, entity.method_23321(),
							8, 0.3, 0.3, 0.3, 0.2
					);
				});
				level.method_8396(
						null, player.method_23312(), class_3417.field_15150/*? if >= 1.21.7 {*/.comp_349()/*?}*/,
						class_3419.field_15248, 1.0F, 0.2F + level.field_9229.method_43057() * 0.3F
				);
				//? if 1.21.1 {
                            /*level.registryAccess().registryOrThrow(Registries.ITEM).getTag(ReArm.SHIELDS).ifPresent(tag ->
                                    tag.forEach(item -> player.getCooldowns().addCooldown(item.value(), ReArm.CONFIG.shield.bashShieldCooldown.get() * 20))
                            );
                            *///?} else {
				level.method_30349().method_30530(class_7924.field_41197).method_40286(ReArm.SHIELDS).forEach(item ->
						player.method_7357().method_7906(level.method_30349().method_30530(class_7924.field_41197).method_10221(item.comp_349()), ReArm.CONFIG.shield.bashShieldCooldown.get() * 20)
				);
				//?}
				player.method_6030().method_7970(
						targets.size(), player,
						player.method_6047().method_31574(player.method_6030().method_7909()) ? class_1304.field_6173 : class_1304.field_6171
				);
				player.method_6021();
			}
		}
	}
}
